.. role:: small
.. role:: smaller

Release Notes
=============

Version 0.3 :small:`April 2021`
-----------------------------------
API change: predict methods changed to transform

Version 0.2 :small:`December 2020`
-----------------------------------
First release of skdim.